@@ -614,6 +614,9 @@ object.
                 sudo on the instance without providing a password,
                 or functionality of this server will be limited.
 
+In addition, you may use any of the options recognized by
+VM::EC2->run_instances() (e.g. -block_devices).
+
 =cut
 
 sub provision_server {
@@ -1184,7 +1187,10 @@ sub rsync {
     }
 
     if ($source_host eq $dest_host) {
-	return $source_host->ssh('sudo','rsync',$rsync_args,@source_paths,$dest_path);
+	$self->info("Beginning rsync @source_paths $dest_path...\n");
+	my $result = $source_host->ssh('sudo','rsync',$rsync_args,@source_paths,$dest_path);
+	$self->info("...rsync done.\n");
+	return $result;
     }
 
     # DataTransferServer1 => DataTransferServer2
@@ -1196,10 +1202,13 @@ sub rsync {
     my $ssh_args = $source_host->_ssh_escaped_args;
     my $keyfile  = $source_host->keyfile;
     $ssh_args    =~ s/$keyfile/$keyname/;  # because keyfile is embedded among args
-    return $source_host->ssh('sudo','rsync',$rsync_args,
-			     '-e',"'ssh $ssh_args'",
-			     "--rsync-path='sudo rsync'",
-			     @source_paths,"$dest_ip:$dest_path");
+    $self->info("Beginning rsync @source_paths $dest_ip:$dest_path...\n");
+    my $result = $source_host->ssh('sudo','rsync',$rsync_args,
+				   '-e',"'ssh $ssh_args'",
+				   "--rsync-path='sudo rsync'",
+				   @source_paths,"$dest_ip:$dest_path");
+    $self->info("...rsync done.\n");
+    return $result;
 }
 
 =head2 $manager->dd($source_vol=>$dest_vol)
@@ -1281,8 +1290,11 @@ sub _resolve_path {
 
 sub _rsync_args {
     my $self  = shift;
-    my $quiet = $self->verbosity < VERBOSE_DEBUG; 
-    return $quiet ? '-aqz' : '-avz';
+    my $verbosity = $self->verbosity;
+    return $verbosity < VERBOSE_WARN  ? '-aqz'
+	  :$verbosity < VERBOSE_INFO  ? '-aqz'
+	  :$verbosity < VERBOSE_DEBUG ? '-az'
+	  : '-avz'
 }
 
 sub _authorize {
@@ -1742,7 +1754,10 @@ sub _scan_volumes {
 	}
 
 	my $vol = $self->volume_class()->new(%args);
-	$vol->mounted(defined $args{-mtpt} && $args{-server});
+	if ($args{-mtpt} && $args{-server}) {
+	    $vol->mounted(1) if $args{-server}->ping && 
+		             $args{-server}->scmd('cat /etc/mtab')=~ $args{-mtpt};
+	}
 	$self->register_volume($vol);
     }
 }
@@ -2034,7 +2049,6 @@ sub _servers {
     return grep {$_->ec2->endpoint eq $endpoint} @servers;
 }
 
-
 sub DESTROY {
     my $self = shift;
     if ($$ == $self->pid) {
